.. _constants:

========================
c-ares library constants
========================


Channel flags
=============

.. py:data:: pycares.ARES_FLAG_USEVC
.. py:data:: pycares.ARES_FLAG_PRIMARY
.. py:data:: pycares.ARES_FLAG_IGNTC
.. py:data:: pycares.ARES_FLAG_NORECURSE
.. py:data:: pycares.ARES_FLAG_STAYOPEN
.. py:data:: pycares.ARES_FLAG_NOSEARCH
.. py:data:: pycares.ARES_FLAG_NOALIASES
.. py:data:: pycares.ARES_FLAG_NOCHECKRESP

.. seealso::
    `c-ares documentation for ares_init <https://c-ares.org/ares_init.html>`_


Nameinfo constants
==================

.. py:data:: pycares.ARES_NI_NOFQDN
.. py:data:: pycares.ARES_NI_NUMERICHOST
.. py:data:: pycares.ARES_NI_NAMEREQD
.. py:data:: pycares.ARES_NI_NUMERICSERV
.. py:data:: pycares.ARES_NI_DGRAM
.. py:data:: pycares.ARES_NI_TCP
.. py:data:: pycares.ARES_NI_UDP
.. py:data:: pycares.ARES_NI_SCTP
.. py:data:: pycares.ARES_NI_DCCP
.. py:data:: pycares.ARES_NI_NUMERICSCOPE
.. py:data:: pycares.ARES_NI_LOOKUPHOST
.. py:data:: pycares.ARES_NI_LOOKUPSERVICE
.. py:data:: pycares.ARES_NI_IDN
.. py:data:: pycares.ARES_NI_IDN_ALLOW_UNASSIGNED
.. py:data:: pycares.ARES_NI_IDN_USE_STD3_ASCII_RULES

.. seealso::
    `c-ares documentation for ares_getnameinfo <https://c-ares.org/ares_getnameinfo.html>`_

Others
======

.. py:data:: pycares.ARES_SOCKET_BAD


